@@ -31,12 +31,11 @@ from .filesystem import (
     JINJA_PATH,
     TemplateDict,
     NamedTemplateDict,
-    _FileLinker,
+    FileLinker,
     LINKER_MAP,
 )
 
 if TYPE_CHECKING:
-    from pathlib import Path
     from typing import Iterable, Optional, ClassVar, Dict
 
     from .base import ModCommand
@@ -47,21 +46,6 @@ def data_name(name: str, mode: LinkMode) -> str:
     return str(NAMES.rel_data_path(name, mode))
 
 
-# def _apply_modification(mod: ModCommand, template_dict: TemplateDict):
-#     match mod:
-#         case RemoveCommand(mode, source):
-#             template_dict[NAMES.convert_mode(mode)].remove(source)
-
-#         case AddCommand(mode, source, index):
-#             template_dict[NAMES.convert_mode(mode)].insert(index, source)
-
-#         case UpdateCommand(mode, source, target):
-#             template_dict[NAMES.convert_mode(mode)] = [
-#                 target if val == source else val
-#                 for val in template_dict[NAMES.convert_mode(mode)]
-#             ]
-
-
 def apply_template_dict_modification(
     template_dict: TemplateDict, mod: ModCommand
 ) -> RuntimeClosure:
@@ -241,7 +225,7 @@ def _link_helper(
 def link_name(
     proj_path: ProjectPath,
     state: Dict,
-    linker: _FileLinker,
+    linker: FileLinker,
     name: str,
     force: bool = False,
     target_dir: Optional[Path] = None,
@@ -260,7 +244,7 @@ def link_name(
 def link_path(
     proj_path: ProjectPath,
     state: Dict,
-    linker: _FileLinker,
+    linker: FileLinker,
     source_path: Path,
     force: bool = False,
 ) -> RuntimeClosure:
@@ -360,13 +344,18 @@ class InfoFileWriter(AtomicIterable):
 
 
 def write_template_dict(
-    proj_path: ProjectPath, template_dict: TemplateDict
+    proj_path: ProjectPath, template_dict: TemplateDict, force=True
 ) -> RuntimeClosure:
     def _callable():
         proj_path.mk_data_dir()
         template_dict.dump(proj_path.template)
         return RuntimeOutput(True)
 
+    if proj_path.template.exists() and not force:
+        return RuntimeClosure(
+            FORMAT_MESSAGE.error("Template dict already exists!"), *FAIL
+        )
+
     return RuntimeClosure(
         FORMAT_MESSAGE.template_dict(
             proj_path.data_dir, overwrite=proj_path.template.exists()
@@ -387,7 +376,10 @@ class TemplateDictWriter(AtomicIterable):
         yield write_template_dict(proj_path, template_dict)
 
 
+@dataclass
 class OutputFolderCreator(AtomicIterable):
+    force: bool = False
+
     def __call__(
         self,
         proj_path: ProjectPath,
@@ -396,7 +388,7 @@ class OutputFolderCreator(AtomicIterable):
         temp_dir: Path,
     ) -> Iterable[RuntimeClosure]:
         """Write top-level files into the project path."""
-        yield write_template_dict(proj_path, template_dict)
+        yield write_template_dict(proj_path, template_dict, force=self.force)
         for source, target in [
             (JINJA_PATH.template_doc(template_dict.name), proj_path.main),
             (JINJA_PATH.project_macro, proj_path.project_macro),
