@@ -9,9 +9,8 @@ import click
 from . import __repo__
 
 if TYPE_CHECKING:
-    from pathlib import Path
     from typing import Iterable, Final
-    from .template import _FileLinker
+    from .filesystem import FileLinker
 
 REPO_FORMATTED = click.style(__repo__, fg="bright_blue")
 
@@ -30,22 +29,23 @@ def redact(obj: str):
 class _MessageFormatter:
     """Formatting messages before printing to the terminal."""
 
-    _prefix = {
-        "cmd": "$ ",
-        "file": "> ",
-        "info": "% ",
-        "err": "! ",
+    _prefix: Final = {
+        "cmd": "$",
+        "file": ">",
+        "info": "%",
+        "err": "!",
+        "prompt": "?",
     }
-    _opts = {
+    _opts: Final = {
         "info": dict(fg="blue"),
         "ok": dict(fg="green"),
         "warn": dict(fg="yellow"),
         "err": dict(fg="red"),
     }
 
-    def _apply_style(self, msg: str, prefix, fmt):
+    def _apply_style(self, msg: str, prefix: str, fmt: str):
         """Helper to apply the prefix and format styles to the message."""
-        return click.style(self._prefix[prefix] + msg, **self._opts[fmt])
+        return click.style(self._prefix[prefix], **self._opts[fmt]) + " " + msg
 
     def render(self, template_path: Path, target: Path, overwrite: bool = False):
         """Format for rendering."""
@@ -54,9 +54,12 @@ class _MessageFormatter:
         if overwrite:
             return self._apply_style("Re-render" + base_str, pref, "warn")
         else:
-            return self._apply_style("Render" + base_str, pref, "info")
+            return self._apply_style("Render" + base_str, pref, "ok")
 
-    def link(self, linker: _FileLinker, name: str, target_dir: Path, mode: str):
+    def prompt(self, prompt: str):
+        return self._apply_style(prompt, "prompt", "info")
+
+    def link(self, linker: FileLinker, name: str, target_dir: Path, mode: str):
         """TODO: write"""
 
         def helper(prop):
@@ -100,7 +103,8 @@ class _MessageFormatter:
 
     def archive(self, output_path: Path, compression: str):
         return self._apply_style(
-            f"Create compressed archive '{output_path}' with compression '{compression}'.",
+            f"Create compressed archive '{output_path}' with compression"
+            f" '{compression}'.",
             "info",
             "ok",
         )
